/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * CameraPositionData.h
 *
 *  Created on: Apr 10, 2010
 *      Author: lziegler
 */

#ifndef CAMERAPOSITIONDATA_H_
#define CAMERAPOSITIONDATA_H_

#include "Type.h"

namespace airobots {

class CameraPositionData: public Type {

public:

	static std::string getBaseTag();

	static std::string getTemplate();

	CameraPositionData();

	/**
	 * Returns the horizontal angle value as radiant for the new position.
	 */
	double getPan() const;
	void setPan(double pan);

	/**
	 * Returns the vertical angle value as radiant for the new position.
	 */
	double getTilt() const;
	void setTilt(double tilt);

	/**
	 * Returns the desired zoom level as percent of the maximum zoom of the
	 * camera [0,1].
	 */
	double getZoom() const;
	void setZoom(double zoom);

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, CameraPositionData &type);

private:

	double pan;
	double tilt;

	double zoom;

};

}

#endif /* CAMERAPOSITIONDATA_H_ */
