/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; c-file-offsets: ((substatement-open . 0)) -*- */
/**
 * @file     navgoaldata.h
 * @author   Roland Philippsen
 * @date     14.09.2006
 * @brief    Converting and extracting navgoal data to and from xml-structure
 */

#ifndef NAVGOALDATA_H
#define NAVGOALDATA_H

#include <string>
#include <cmath>

#include <xmltio/xmltio.hpp>

#include "PositionData.h"

namespace airobots {

class NavigationGoalData: public PositionData {

public:

	enum NavgoalType {
		LOCAL, GLOBAL
	};

	static const float DEFAULT_DR = 0.3;
	static const float DEFAULT_DTHETA = M_PI;

	static std::string getBaseTag();

	static std::string getTemplate();

	NavigationGoalData();
	NavigationGoalData(std::string generator, float x, float y, float theta,
			float dr = DEFAULT_DR, float dtheta = DEFAULT_DTHETA,
			NavgoalType type = LOCAL);

	float getDR() const;
	float getDTheta() const;
	NavgoalType getType() const;
	void setDR(float dR);
	void setDTheta(float dTheta);
	void setType(NavgoalType type);

	bool operator==(const NavigationGoalData &other) const;

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, NavigationGoalData &type);

private:
	float dR;
	float dTheta;
	NavgoalType type;

};

std::ostream& operator<<(std::ostream& o, NavigationGoalData const& ngd);

}

#endif // NAVGOALDATA_H
