/*
 * PointCloudGrasping.cpp
 *
 *  Created on: Jun 14, 2011
 *      Author: plueckin
 */

#include "PointCloudGrasping.h"

using namespace airobots;
using namespace xmltio;
using namespace std;

PointCloudGrasping::PointCloudGrasping() : Type() {
	iLU = MILLIMETER;
}

PointCloudGrasping::PointCloudGrasping(std::string generator) : Type(generator) {
	iLU = MILLIMETER;
}

PointCloudGrasping::PointCloudGrasping(const PointCloudGrasping &other) {
	iLU = other.iLU;
	convex_hull = other.convex_hull;
	grasppnt = other.grasppnt;
	label = other.label;
	height = other.height;
	width = other.width;
	depth = other.depth;
}

PointCloudGrasping::PointCloudGrasping(PointCloud chull, Point3D gpnt,
		string lbl, double h, double w, double d, LengthUnit ilu) :
	convex_hull(chull), grasppnt(gpnt), label(lbl), height(h), width(w),
			depth(d), iLU(ilu) {
}

PointCloudGrasping::~PointCloudGrasping() {
	// TODO Auto-generated destructor stub
}

string PointCloudGrasping::getBaseTag() {
	return "POINTCLOUDGRASPING";
}

string PointCloudGrasping::getTemplate() {
	return std::string("<") + getBaseTag() + "><GENERATOR/>"
			+ Timestamp::getTemplate()
			+ "<GRASPING_POINT x=\"\" y=\"\" z=\"\" />"
			+ "<LABEL value=\"\" />" + +"<HEIGHT valh=\"\" />"
			+ "<WIDTH valw=\"\" />" + "<DEPTH vald=\"\" />" + "</"
			+ getBaseTag() + ">";
}

void PointCloudGrasping::fillInto(Location &loc) const {
	Type::fillInto(loc);

	loc[XPath("GRASPING_POINT/@x")] = grasppnt.getX(iLU);
	loc[XPath("GRASPING_POINT/@y")] = grasppnt.getY(iLU);
	loc[XPath("GRASPING_POINT/@z")] = grasppnt.getZ(iLU);
	loc[XPath("LABEL/@value")] = label;
	loc[XPath("HEIGHT/@valh")] = height;
	loc[XPath("WIDTH/@valw")] = width;
	loc[XPath("DEPTH/@vald")] = depth;

	Location loc_hull(PointCloud::getTemplate(),
			XPath(PointCloud::getBaseTag()));
	convex_hull.fillInto(loc_hull);

	loc.add(loc_hull);
}

void PointCloudGrasping::fromLocation(const Location &loc,
		PointCloudGrasping &pcg) {
	Type::fromLocation(loc, pcg);

	for (XPathIterator iter = XPath(PointCloud::getBaseTag()).evaluate(loc); iter; ++iter) {
		PointCloud pc;
		PointCloud::fromLocation(*iter, pc);
		pcg.setHull(pc);
	}

	double grspx = extract<double> (loc[XPath("GRASPING_POINT/@x")]);
	double grspy = extract<double> (loc[XPath("GRASPING_POINT/@y")]);
	double grspz = extract<double> (loc[XPath("GRASPING_POINT/@z")]);
	Point3D grsp = Point3D(grspx, grspy, grspz, pcg.iLU);

	double h = extract<double> (loc[XPath("HEIGHT/@valh")]);
	double w = extract<double> (loc[XPath("WIDTH/@valw")]);
	double d = extract<double> (loc[XPath("DEPTH/@vald")]);

	string lbl = extract<string> (loc[XPath("LABEL/@value")]);

	pcg.setGraspPnt(grsp);
	pcg.setLabel(lbl);
	pcg.setHeight(h);
	pcg.setWidth(w);
	pcg.setDepth(d);
}

void PointCloudGrasping::sanitizeLocation(Location &loc) const {
	XPath xp(getBaseTag());
	while (XPathIterator i = xp.evaluate(loc)) {
		Location l(*i);
		loc.remove(l);
	}
}

bool PointCloudGrasping::operator==(const PointCloudGrasping &other) const {
	if ((other.height != height) || (other.width != width) || (other.depth
			!= depth))
		return false;
	if (!(other.grasppnt == grasppnt))
		return false;
	if (!(other.label == label))
		return false;
	if (!(other.convex_hull == convex_hull))
		return false;
	return true;
}

void PointCloudGrasping::setHull(PointCloud pc) {
	this->convex_hull = pc;
}

void PointCloudGrasping::setGraspPnt(Point3D gpnt) {
	this->grasppnt = gpnt;
}

void PointCloudGrasping::setLabel(string label) {
	this->label = label;
}

void PointCloudGrasping::setHeight(double h) {
	this->height = h;
}

void PointCloudGrasping::setWidth(double w) {
	this->width = w;
}

void PointCloudGrasping::setDepth(double d) {
	this->depth = d;
}

PointCloud PointCloudGrasping::getHull() {
	return convex_hull;
}

Point3D PointCloudGrasping::getGraspPnt() {
	return grasppnt;
}

std::string PointCloudGrasping::getLabel() {
	return label;
}

double PointCloudGrasping::getHeight() {
	return height;
}

double PointCloudGrasping::getWidth() {
	return width;
}

double PointCloudGrasping::getDepth() {
	return depth;
}


