/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data;

import nu.xom.Attribute;
import nu.xom.Element;
import nu.xom.Node;
import nu.xom.Nodes;
import de.unibi.airobots.btl.common.ElementParser;

public class Shirt extends Type implements Percept {

	@Override
	public String getPerceptName() {
		return "shirt";
	}

	public static String getBaseTag() {
		return "SHIRT";
	}

	public static void fromElement(Element element, Shirt type) {

		Type.fromElement(element, type);

		Nodes nodes = element.query("*");
		for (int i = 0; i < nodes.size(); i++) {
			Node node = nodes.get(i);
			if (node instanceof Element) {
				Element elem = (Element) node;
				if (elem.getLocalName().equals("POSITION")) {
					type.setAngle((float) ElementParser
							.getDoubleAttributeValue(elem, "angle"));
					type.setAngleVariance((float) ElementParser
							.getDoubleAttributeValue(elem, "angleVariance"));
					type.setDistance((float) ElementParser
							.getDoubleAttributeValue(elem, "distance"));
					type.setDistanceVariance((float) ElementParser
							.getDoubleAttributeValue(elem, "distanceVariance"));
				}
			}
		}

	}

	public void fillInto(Element parent) {

		super.fillInto(parent);

		Element posElement = new Element("POSITION");
		parent.appendChild(posElement);
		posElement.addAttribute(new Attribute("" + "angle", String
				.valueOf(getAngle())));
		posElement.addAttribute(new Attribute("" + "angleVariance", String
				.valueOf(getAngleVariance())));
		posElement.addAttribute(new Attribute("" + "distance", String
				.valueOf(getDistance())));
		posElement.addAttribute(new Attribute("" + "distanceVariance", String
				.valueOf(getDistanceVariance())));

	}

	public void setAngle(float angle) {
		this.angle = angle;
	}

	public float getAngle() {
		return angle;
	}

	public void setAngleVariance(float angleVariance) {
		this.angleVariance = angleVariance;
	}

	public float getAngleVariance() {
		return angleVariance;
	}

	public void setDistance(float distance) {
		this.distance = distance;
	}

	public float getDistance() {
		return distance;
	}

	public void setDistanceVariance(float distanceVariance) {
		this.distanceVariance = distanceVariance;
	}

	public float getDistanceVariance() {
		return distanceVariance;
	}

	public boolean equals(Shirt other) {
		return (this.getAngle() == other.getAngle())
				&& (this.getAngleVariance() == other.getAngleVariance())
				&& (this.getDistance() == other.getDistance())
				&& (this.getDistanceVariance() == other.getDistanceVariance());
	}

	/** The angle to the shirt percept. */
	private float angle;

	/** The variance in the angle value. */
	private float angleVariance;

	/** The distance to the shirt percept. */
	private float distance;

	/** The variance in the distance values. */
	private float distanceVariance;

}
