/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data;

import nu.xom.Attribute;
import nu.xom.Element;
import de.unibi.airobots.btl.common.ElementParser;

/**
 * This class is used to store data from the sonar sensors from nao. It holds
 * the distances to objects in front of the left or right sensor.
 * 
 * @author sebschne
 */
public class SonarData extends Type {

	private double distanceRight;
	private double distanceLeft;

	public SonarData(double distanceRight, double distanceLeft) {
		super();
		this.distanceRight = distanceRight;
		this.distanceLeft = distanceLeft;
	}

	public static String getBaseTag() {
		return "SONARDATA";
	}

	/**
	 * 
	 * @return the observed distance to an object in front of the right sonar
	 *         sensor.
	 */
	public double getDistanceRight() {
		return distanceRight;
	}

	/**
	 * 
	 * @return the observed distance to an object in front of the left sonar
	 *         sensor.
	 */
	public double getDistanceLeft() {
		return distanceLeft;
	}

	public void setDistanceRight(double distanceRight) {
		this.distanceRight = distanceRight;
	}

	public void setDistanceLeft(double distanceLeft) {
		this.distanceLeft = distanceLeft;
	}

	public static void fromElement(Element element, SonarData type) {

		Type.fromElement(element, type);

		Element leftElement = element.getFirstChildElement("DISTLEFT");
		type.setDistanceLeft(ElementParser.getDoubleAttributeValue(leftElement,
				"value"));
		Element rightElement = element.getFirstChildElement("DISTRIGHT");
		type.setDistanceRight(ElementParser.getDoubleAttributeValue(
				rightElement, "value"));

	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void fillInto(Element parent) {
		super.fillInto(parent);

		Element rightElement = new Element("DISTRIGHT");
		parent.appendChild(rightElement);
		rightElement.addAttribute(new Attribute("value", String
				.valueOf(getDistanceRight())));
		Element leftElement = new Element("DISTLEFT");
		parent.appendChild(leftElement);
		leftElement.addAttribute(new Attribute("value", String
				.valueOf(getDistanceLeft())));

	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {

		return "Created: " + getTimestamp() + " Distance left:  "
				+ getDistanceLeft() + " Distance right " + getDistanceRight();

	}

}
