/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.speechrec;

import java.util.ArrayList;

/**
 * Domain class representing a non terminal symbol within the grammartree of an
 * utterance
 * 
 * @author lschilli
 */
public class GrammarNonTerminal implements GrammarSymbol {

	private String name;
	private ArrayList<GrammarSymbol> subsymbols = new ArrayList<GrammarSymbol>();

	public GrammarNonTerminal() {

	}

	GrammarNonTerminal(String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public GrammarSymbol getSymbol(int index) {
		return subsymbols.get(index);
	}

	public int size() {
		return subsymbols.size();
	}

	public void addSymbol(GrammarSymbol sym) {
		subsymbols.add(sym);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		StringBuilder strb = new StringBuilder();
		strb.append(name + ":\n");
		for (int i = 0; i < subsymbols.size(); i++) {
			GrammarSymbol sym = subsymbols.get(i);
			strb.append(sym + "\n");
		}
		return strb.toString();
	}
}