/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.taskpattern;

import nu.xom.Element;
import nu.xom.Node;
import nu.xom.Nodes;
import de.unibi.airobots.btl.common.ElementParser;

/**
 * Task wait for ten seconds. send by the dialog to the system, which must handle this task.
 * 
 * @author arothert
 */
public class WaitForTenSec extends TaskPatternBase {

	public WaitForTenSec() {
	}


/**
		 * the base tag should be named after the class itself.
		 * @return
		 */
		public static String getBaseTag() {
			return "WAIT_FOR_TEN_SEC";
		}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void fillInto(Element parent) {
		super.fillInto(parent);

		Element statesElement =
				TaskPatternStatusTagData.createTaskStatusElement(getOrigin(), getValue());
		parent.appendChild(statesElement);

	}

	public static void fromElement(Element element, WaitForTenSec type) {

		Nodes nodes = element.query("*");
		for (int i = 0; i < nodes.size(); i++) {
			Node node = nodes.get(i);
			if (node instanceof Element) {
				Element elem = (Element) node;
				if (elem.getLocalName().equals(STATUS_TAG)) {
					type.setValue(ElementParser.getAttributeValue(elem, VALUE_ATT));
					type.setOrigin(ElementParser.getAttributeValue(elem, ORIGIN_ATT));
				}
			}
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		StringBuilder strb = new StringBuilder();
		strb.append("[" + getBaseTag() + ": ");
		strb.append("[STATUS: ");
		strb.append("value: " + getValue() + "; ");
		strb.append("origin: " + getOrigin() + "]] ");
		return strb.toString();
	}
}
